@@ -10,8 +10,9 @@ EXAMPLES::
     Options:
       --help  Show this message and exit.
     Commands:
-      cv        Digitize a cylic voltammogram.
-      digitize  Digitize a plot.
+      cv        Digitize a cylic voltammogram and create a frictionless...
+      digitize  Digitize a 2D plot.
+      figure    Digitize a figure with units on the axis and create a...
       paginate  Render PDF pages as individual SVG files with linked PNG images.
       plot      Display a plot of the data traced in an SVG.
 
@@ -73,6 +74,20 @@ si_option = click.option(
     help="Convert units of the plot and CSV to SI (only if they are compatible with astropy units).",
 )
 
+sampling_interval_option = click.option(
+    "--sampling-interval",
+    type=float,
+    default=None,
+    help="Sampling interval on the x-axis with respect to the x-axis values.",
+)
+
+outdir_option = click.option(
+    "--outdir",
+    type=click.Path(file_okay=False),
+    default=None,
+    help="Write output files to this directory.",
+)
+
 
 def _outfile(template, suffix=None, outdir=None):
     r"""
@@ -142,7 +157,7 @@ def _create_bibliography(svg, metadata):
     Return a bibtex string built from a BIB file and a key provided in `metadata['source']['citation key']`,
     when both requirements are met. Otherwise an empty string is returned.
 
-    This is a helper method for :meth:`digitize_cv`.
+    This is a helper method for :meth:`_create_outfiles`.
     """
     from pybtex.database import parse_file
 
@@ -171,17 +186,13 @@ def _create_bibliography(svg, metadata):
 
 
 @click.command()
-@click.option(
-    "--sampling-interval",
-    type=float,
-    default=None,
-    help="Sampling interval on the x-axis.",
-)
+@sampling_interval_option
 @skewed_option
 @click.argument("svg", type=click.File("rb"))
 def plot(svg, sampling_interval, skewed):
-    r"""
+    """
     Display a plot of the data traced in an SVG.
+    \f
 
     EXAMPLES::
 
@@ -195,25 +206,16 @@ def plot(svg, sampling_interval, skewed):
 
 
 @click.command()
-@click.option(
-    "--sampling-interval",
-    type=float,
-    default=None,
-    help="Sampling interval on the x-axis.",
-)
-@click.option(
-    "--outdir",
-    type=click.Path(file_okay=False),
-    default=None,
-    help="write output files to this directory",
-)
+@sampling_interval_option
+@outdir_option
 @skewed_option
 @click.argument("svg", type=click.Path(exists=True))
 def digitize(svg, sampling_interval, outdir, skewed):
-    r"""
-    Digitize a plot.
+    """
+    Digitize a 2D plot.
 
     Produces a CSV from the curve traced in the SVG.
+    \f
 
     EXAMPLES::
 
@@ -230,34 +232,98 @@ def digitize(svg, sampling_interval, outdir, skewed):
     svg_plot.df.to_csv(_outfile(svg, suffix=".csv", outdir=outdir), index=False)
 
 
-@click.command(name="cv")
-@click.option(
-    "--sampling-interval",
-    type=float,
-    default=None,
-    help="sampling interval on the x-axis in volts",
-)
+@click.command(name="figure")
+@sampling_interval_option
+@outdir_option
 @click.option(
     "--metadata", type=click.File("rb"), default=None, help="yaml file with metadata"
 )
-@click.option("--package", is_flag=True, help="create .json in data package format")
-@click.option(
-    "--outdir",
-    type=click.Path(file_okay=False),
-    default=None,
-    help="write output files to this directory",
-)
 @click.argument("svg", type=click.Path(exists=True))
 @si_option
 @bibliography_option
 @skewed_option
-def digitize_cv(
-    svg, sampling_interval, metadata, package, outdir, skewed, bibliography, si_units
+def digitize_figure(
+    svg, sampling_interval, metadata, outdir, bibliography, skewed, si_units
 ):
-    r"""
-    Digitize a cylic voltammogram.
+    """
+    Digitize a figure with units on the axis and create a frictionless datapackage.
 
-    For inclusion in the echemdb.
+    The resulting CVS contains a time axis, when text label with a scan rate is given
+    in the SVG whose units must be of type `x-axis unit / time unit`, such as `scan rate: 50 K / s`.
+    \f
+
+    EXAMPLES::
+
+        >>> from svgdigitizer.test.cli import invoke, TemporaryData
+        >>> with TemporaryData("**/xy_rate.svg") as directory:
+        ...     invoke(cli, "figure", os.path.join(directory, "xy_rate.svg"))
+
+    TESTS:
+
+    The command can be invoked on files in the current directory::
+
+        >>> from svgdigitizer.test.cli import invoke, TemporaryData
+        >>> cwd = os.getcwd()
+        >>> with TemporaryData("**/xy_rate.svg") as directory:
+        ...     os.chdir(directory)
+        ...     try:
+        ...         invoke(cli, "figure", "xy_rate.svg")
+        ...     finally:
+        ...         os.chdir(cwd)
+
+    The command can be invoked without sampling when data is not given in volts::
+
+        >>> from svgdigitizer.test.cli import invoke, TemporaryData
+        >>> from svgdigitizer.svg import SVG
+        >>> from svgdigitizer.svgplot import SVGPlot
+        >>> from svgdigitizer.svgfigure import SVGFigure
+        >>> with TemporaryData("**/xy_rate.svg") as directory:
+        ...     with open(os.path.join(directory, "xy_rate.svg"), mode="rb") as svg:
+        ...         print(SVGFigure(SVGPlot(SVG(svg))).figure_schema.get_field("E").custom["unit"])
+        mV
+        >>> with TemporaryData("**/xy_rate.svg") as directory:
+        ...     invoke(cli, "figure", os.path.join(directory, "xy_rate.svg"))
+
+    """
+    if metadata:
+        import yaml
+
+        metadata = yaml.load(metadata, Loader=yaml.SafeLoader)
+
+    with open(svg, mode="rb") as infile:
+        from svgdigitizer.svgfigure import SVGFigure
+
+        svgfigure = SVGFigure(
+            _create_svgplot(infile, sampling_interval=sampling_interval, skewed=skewed),
+            metadata=metadata,
+            force_si_units=si_units,
+        )
+
+    _create_outfiles(
+        svgfigure=svgfigure, svg=svg, outdir=outdir, bibliography=bibliography
+    )
+
+
+@click.command(name="cv")
+@sampling_interval_option
+@outdir_option
+@click.option(
+    "--metadata", type=click.File("rb"), default=None, help="yaml file with metadata"
+)
+@click.argument("svg", type=click.Path(exists=True))
+@bibliography_option
+@si_option
+@skewed_option
+def digitize_cv(
+    svg, sampling_interval, metadata, outdir, skewed, bibliography, si_units
+):
+    """
+    Digitize a cylic voltammogram and create a frictionless datapackage.
+
+    The sampling interval should be provided in mV.
+
+    For inclusion in www.echemdb.org.
+    \f
 
     EXAMPLES::
 
@@ -278,7 +344,7 @@ def digitize_cv(
         ...     finally:
         ...         os.chdir(cwd)
 
-    The command can be invoked without sampling when data is not given in volts::
+    The command can be invoked without sampling when data is git not given in volts::
 
         >>> from svgdigitizer.test.cli import invoke, TemporaryData
         >>> from svgdigitizer.svg import SVG
@@ -306,7 +372,9 @@ def digitize_cv(
 
             sampling_interval /= u.Unit(
                 cv.figure_schema.get_field(cv.svgplot.xlabel).custom["unit"]
-            ).to(u.V)
+            ).to(
+                u.V  # pylint: disable=no-member
+            )
 
     if metadata:
         import yaml
@@ -314,36 +382,46 @@ def digitize_cv(
         metadata = yaml.load(metadata, Loader=yaml.SafeLoader)
 
     with open(svg, mode="rb") as infile:
-        cv = CV(
+        svgfigure = CV(
             _create_svgplot(infile, sampling_interval=sampling_interval, skewed=skewed),
             metadata=metadata,
             force_si_units=si_units,
         )
 
-    csvname = _outfile(svg, suffix=".csv", outdir=outdir)
-    cv.df.to_csv(csvname, index=False)
+    _create_outfiles(
+        svgfigure=svgfigure, svg=svg, outdir=outdir, bibliography=bibliography
+    )
 
-    metadata = cv.metadata
+
+def _create_outfiles(svgfigure, svg, outdir, bibliography):
+    """Writes a datapackage consisting of a CSV and JSON file from a :param:'svgfigure'
+
+    This is a helper method for CLI commands that digitize an svgfigure.
+    """
+    csvname = _outfile(svg, suffix=".csv", outdir=outdir)
+    svgfigure.df.to_csv(csvname, index=False)
+
+    metadata = svgfigure.metadata
 
     if bibliography:
-        metadata.setdefault("bibliography", {})
+        metadata.setdefault("source", {})
+        metadata["source"].setdefault("bibdata", {})
 
-        if metadata["bibliography"]:
+        if metadata["source"]["bibdata"]:
             logger.warning(
                 "The key with name `bibliography` in the metadata will be overwritten with the new bibliography data."
             )
 
-        metadata.update({"bibliography": _create_bibliography(svg, metadata)})
+        metadata["source"].update({"bibdata": _create_bibliography(svg, metadata)})
 
-    if package:
-        package = _create_package(metadata, csvname, outdir)
+    package = _create_package(metadata, csvname, outdir)
 
     with open(
         _outfile(svg, suffix=".json", outdir=outdir),
         mode="w",
         encoding="utf-8",
     ) as json:
-        _write_metadata(json, package.to_dict() if package else metadata)
+        _write_metadata(json, package.to_dict())
 
 
 def _create_package(metadata, csvname, outdir):
@@ -351,7 +429,7 @@ def _create_package(metadata, csvname, outdir):
     Return a data package built from a :param:`metadata` dict and tabular data
     in :param:`csvname`.
 
-    This is a helper method for :meth:`digitize_cv`.
+    This is a helper method for :meth:`_create_outfiles`.
     """
     from frictionless import Package, Resource, Schema
 
@@ -364,12 +442,15 @@ def _create_package(metadata, csvname, outdir):
         ],
     )
     package.infer()
-    package.custom = metadata
+    resource = package.resources[0]
+
+    resource.custom.setdefault("metadata", {})
+    resource.custom["metadata"].setdefault("echemdb", metadata)
 
     # Update fields in the datapackage describing the data in the CSV
-    package_schema = package.resources[0].schema
+    package_schema = resource.schema
     data_description_schema = Schema.from_descriptor(
-        {"fields": package.custom["data description"]["fields"]}
+        {"fields": resource.custom["metadata"]["echemdb"]["data description"]["fields"]}
     )
 
     new_fields = []
@@ -383,8 +464,8 @@ def _create_package(metadata, csvname, outdir):
             | package_schema.get_field(name).to_dict()
         )
 
-    package.resources[0].schema = Schema.from_descriptor({"fields": new_fields})
-    del package.custom["data description"]["fields"]
+    resource.schema = Schema.from_descriptor({"fields": new_fields})
+    del resource.custom["metadata"]["echemdb"]["data description"]
 
     return package
 
@@ -393,7 +474,7 @@ def _write_metadata(out, metadata):
     r"""
     Write `metadata` to the `out` stream in JSON format.
 
-    This is a helper method for :meth:`digitize_cv`.
+    This is a helper method for :meth:`_create_outfiles`.
     """
 
     def defaultconverter(item):
@@ -461,19 +542,20 @@ def _create_linked_svg(svg, png):
 
 
 @click.command()
-@click.option("--onlypng", is_flag=True, help="Only produce png files")
+@click.option("--onlypng", is_flag=True, help="Only produce png files.")
 @click.option(
     "--outdir",
     type=click.Path(file_okay=False),
     default=None,
-    help="write output files to this directory",
+    help="Write output files to this directory.",
 )
 @click.argument("pdf")
 def paginate(onlypng, pdf, outdir):
-    r"""
+    """
     Render PDF pages as individual SVG files with linked PNG images.
 
     The SVG and PNG files are written to the PDF's directory.
+    \f
 
     EXAMPLES::
 
@@ -499,6 +581,7 @@ def paginate(onlypng, pdf, outdir):
 
 cli.add_command(plot)
 cli.add_command(digitize)
+cli.add_command(digitize_figure)
 cli.add_command(digitize_cv)
 cli.add_command(paginate)
 
